==> haskell-tar-0.5.1.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.1.0
id: tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7
key: tar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7
license: BSD-3-Clause
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
abi: 9e53709e713a6631a46267ec113c0cfb
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-0.5.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-0.5.1.0
hs-libraries: HStar-0.5.1.0-GcqFpTqelp4Lmy6ZbjHbS7
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.1.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.1.1
id: tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue
key: tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue
license: BSD-3-Clause
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
abi: 098b31e8ada79590d58687395d0398fc
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-0.5.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-0.5.1.1
hs-libraries: HStar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
